Software Heritage Filesystem (SwhFS)
====================================

User-space POSIX filesystem to browse the `Software Heritage
<https://www.softwareheritage.org/>`_ `archive
<https://archive.softwareheritage.org/>`_, as if it were locally available.

Built using the `FUSE <https://github.com/libfuse/libfuse>`_ framework.


Demo
----

A live demo of SwhFS in action is available as a `screencast
<https://www.youtube.com/watch?v=2L4ANVlICaE>`_.


Bibliography
------------

In addition to accompanying technical documentation, SwhFS is also described in
the following scientific paper. If you use SwhFS for your scientific results,
please acknowledge it by citing the paper as follows:

.. note::

  Thibault Allançon, Antoine Pietri, Stefano Zacchiroli. `The Software Heritage
  Filesystem (SwhFS): Integrating Source Code Archival with Development
  <https://arxiv.org/pdf/2102.06390.pdf>`_. In proceedings of `ICSE 2021
  <https://conf.researchr.org/home/icse-2021>`_: The 43rd International
  Conference on Software Engineering, May 2021, Madrid, Spain. IEEE 2021.

  Links: `preprint <https://arxiv.org/pdf/2102.06390.pdf>`_, `bibtex
  <https://upsilon.cc/~zack/research/publications/saner-2020-swh-graph.bib>`_.
